<?php
/**
 * Checks debug and fs method constant and update option.
 */
function dawufeg_debug_fs_check() {

	// when true update option to 0 for debug.
	if ( 1 === intval( constant( 'WP_DEBUG' ) ) ) {
		update_option( 'dawufeg_debug', 1 );
	} else {
		update_option( 'dawufeg_debug', 0 );
	}

	// when true update option to 0 for debug log.
	if ( 1 === intval( constant( 'WP_DEBUG_LOG' ) ) ) {
		update_option( 'dawufeg_debug_log', 1 );
	} else {
		update_option( 'dawufeg_debug_log', 0 );
	}

	// when true update option to 0 for debug display.
	if ( 1 === intval( constant( 'WP_DEBUG_DISPLAY' ) ) ) {
		update_option( 'dawufeg_debug_display', 1 );
	} else {
		update_option( 'dawufeg_debug_display', 0 );
	}

	// if direct value is there update option.
	if ( defined( 'FS_METHOD' ) ) {
		if ( 'direct' === strtolower( strval( constant( 'FS_METHOD' ) ) ) ) {
			update_option( 'dawufeg_fs_method', 1 );
		} else {
			update_option( 'dawufeg_fs_method', 0 );
		}
	} else {
		update_option( 'dawufeg_fs_method', 0 );
	}
}

/**
 * Change setting for debug and fs method.
 */
function dawufeg_debug_setting_callback() {
    // phpcs:disable WordPress.Security.NonceVerification.Recommended

	$config_file_path = strval( dawufeg_get_config_path() ); // config file path.

	// if config file exist and have write permission load wpconfig tranformer.
	if ( $config_file_path && file_exists( $config_file_path ) ) {
		if ( is_writable( $config_file_path ) && current_user_can( 'manage_options' ) ) {
			$config_transformer = new \WPConfigTransformer( $config_file_path );
		}
	}

	// if wp-config.php is writable.
	if ( is_writable( $config_file_path ) && current_user_can( 'manage_options' ) ) {

		// if constant is set to true update chekbox and on false change make constant true.
		if ( 'first' !== get_option( 'edit_first_time' ) ) {
			dawufeg_debug_fs_check();
			add_option( 'edit_first_time', 'first' );
		} elseif ( 'first' === get_option( 'edit_first_time' ) && ! isset( $_GET['settings-updated'] ) ) {
			dawufeg_debug_fs_check();
		} elseif ( 'first' === get_option( 'edit_first_time' ) && isset( $_GET['settings-updated'] ) ) {

			// change debug constant value for debug.
			if ( get_option( 'dawufeg_debug' ) ) {
				if ( $config_transformer->exists( 'constant', 'WP_DEBUG' ) ) {
					$config_transformer->update( 'constant', 'WP_DEBUG', 'true', array( 'raw' => true ) );
				} else {

					// if update fail then display error.
					try {
						$config_transformer->add( 'constant', 'WP_DEBUG', 'true', array( 'raw' => true ) );
					} catch ( \Exception $ex ) {
						update_option( 'dawufeg_debug', 0 );
						add_action( 'admin_notices', 'dawufeg_error_notices_callback' );
					}
				}
			} else {

				// Add constant false if exist.
				if ( $config_transformer->exists( 'constant', 'WP_DEBUG' ) ) {
					$config_transformer->update( 'constant', 'WP_DEBUG', 'false', array( 'raw' => true ) );
				}
			}

			// change debug constant value for debug log.
			if ( get_option( 'dawufeg_debug_log' ) ) {
				if ( $config_transformer->exists( 'constant', 'WP_DEBUG_LOG' ) ) {
					$config_transformer->update( 'constant', 'WP_DEBUG_LOG', 'true', array( 'raw' => true ) );
				} else {

					// if update fail then display error.
					try {
						$config_transformer->add( 'constant', 'WP_DEBUG_LOG', 'true', array( 'raw' => true ) );
					} catch ( \Exception $ex ) {
						update_option( 'dawufeg_debug', 0 );
						add_action( 'admin_notices', 'dawufeg_error_notices_callback' );
					}
				}
			} else {
				if ( $config_transformer->exists( 'constant', 'WP_DEBUG_LOG' ) ) {
					$config_transformer->update( 'constant', 'WP_DEBUG_LOG', 'false', array( 'raw' => true ) );
				}
			}

			// change debug constant value for debug display.
			if ( get_option( 'dawufeg_debug_display' ) ) {
				if ( $config_transformer->exists( 'constant', 'WP_DEBUG_DISPLAY' ) ) {
					$config_transformer->update( 'constant', 'WP_DEBUG_DISPLAY', 'true', array( 'raw' => true ) );
				} else {

					// if update fail then display error.
					try {
						$config_transformer->add( 'constant', 'WP_DEBUG_DISPLAY', 'true', array( 'raw' => true ) );
					} catch ( \Exception $ex ) {
						add_action( 'admin_notices', 'dawufeg_error_notices_callback' );
						update_option( 'dawufeg_debug', 0 );
					}
				}
			} else {
				if ( $config_transformer->exists( 'constant', 'WP_DEBUG_DISPLAY' ) ) {
					$config_transformer->update( 'constant', 'WP_DEBUG_DISPLAY', 'false', array( 'raw' => true ) );
				}
			}

			// change fs method constant value.
			if ( get_option( 'dawufeg_fs_method' ) ) {
				if ( $config_transformer->exists( 'constant', 'FS_METHOD' ) ) {
					$config_transformer->update( 'constant', 'FS_METHOD', 'direct' );
				} else {

					// if update fail then display error.
					try {
						$config_transformer->add( 'constant', 'FS_METHOD', 'direct', array( 'separator' => PHP_EOL ) );
					} catch ( \Exception $ex ) {
						update_option( 'dawufeg_fs_method', 0 );
						add_action( 'admin_notices', 'dawufeg_error_notices_callback' );
					}
				}
			} else {

				// remove constant.
				if ( $config_transformer->exists( 'constant', 'FS_METHOD' ) ) {
					$config_transformer->remove( 'constant', 'FS_METHOD' );
				}
			}
		}
	} else {
		dawufeg_debug_fs_check();
	}
}
