<?php
/**
 * Checks the wp-config file write permission.
 *
 * @return bool
 */
function dawufeg_config_file_permission_check() {
	$config_file_path = strval( dawufeg_get_config_path() );
	if ( is_writable( $config_file_path ) ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Display switch for major updates.
 */
function dawufeg_wordpress_major_updates_callback() { ?>
	<label class="dawufeg-switch" for="dawufeg_core_major">
		<input type="checkbox" id="dawufeg_core_major" name="dawufeg_core_major" value="1" <?php echo checked( 1, get_option( 'dawufeg_core_major' ), false ); ?> />
		<span class="dawufeg-slider dawufeg-round"></span>
	</label>
	<span class="setting-help-tip">
		<div class="tooltipdata">
			<?php esc_html_e( 'Enabling this stops all automatic major updates of your WordPress site.', 'disable-wordpress-automatic-updates-theme-editors' ); ?>
		</div>
	</span>
	<?php
}

/**
 * Display switch for minor updates.
 */
function dawufeg_wordpress_minor_updates_callback() {
	?>
	<label class="dawufeg-switch" for="dawufeg_core_minor">
		<input type="checkbox" id="dawufeg_core_minor" name="dawufeg_core_minor" value="1" <?php echo checked( 1, get_option( 'dawufeg_core_minor' ), false ); ?>/>
		<span class="dawufeg-slider dawufeg-round"></span>
	</label>
	<span class="setting-help-tip">
		<div class="tooltipdata">
			<?php esc_html_e( 'Enabling this stops all automatic minor updates of your WordPress site.', 'disable-wordpress-automatic-updates-theme-editors' ); ?>
		</div>
	</span>
	<?php
}

/**
 * Display switch for plugin update option.
 */
function dawufeg_wordpress_plugin_updates_callback() {
	?>
	<label class="dawufeg-switch" for="dawufeg_plugin">
		<input type="checkbox" id="dawufeg_plugin" name="dawufeg_plugin" value="1" <?php echo checked( 1, get_option( 'dawufeg_plugin' ), false ); ?>/>
		<span class="dawufeg-slider dawufeg-round"></span>
	</label>
	<span class="setting-help-tip">
		<div class="tooltipdata">
			<?php esc_html_e( 'Enable this to pause automatic plugin updates on your site.', 'disable-wordpress-automatic-updates-theme-editors' ); ?>
		</div>
	</span>
	<?php
}

/**
 * Display switch for theme update option.
 */
function dawufeg_wordpress_theme_updates_callback() {
	?>
	<label class="dawufeg-switch" for="dawufeg_theme">
		<input type="checkbox" id="dawufeg_theme" name="dawufeg_theme" value="1" <?php echo checked( 1, get_option( 'dawufeg_theme' ), false ); ?>/>
		<span class="dawufeg-slider dawufeg-round"></span>
	</label>
	<span class="setting-help-tip">
		<div class="tooltipdata">
			<?php esc_html_e( 'Enable this to pause automatic theme updates on your site.', 'disable-wordpress-automatic-updates-theme-editors' ); ?>
		</div>
	</span>
	<?php
}

/**
 *  Display switch for disableing plugin and theme upload button and manual update button.
 */
function dawufeg_wordpress_uploading_callback() {
	?>
	<label class="dawufeg-switch" for="dawufeg_uploads">
		<input type="checkbox" id="dawufeg_uploads" name="dawufeg_uploads" value="1" <?php echo checked( 1, get_option( 'dawufeg_uploads' ), false ); ?>/>
		<span class="dawufeg-slider dawufeg-round"></span>
	</label>
	<span class="setting-help-tip">
		<div class="tooltipdata">
			<?php esc_html_e( "Enable this to remove 'Upload' button from the Plugin's & Theme page and the 'Updates' link that appears below the plugin name on the plugin's & Theme page whenever an update is available.", 'disable-wordpress-automatic-updates-theme-editors' ); ?> <a class="learn-more" href='<?php echo esc_url( plugins_url( 'assets/img/plugin_upload.png', dirname( __FILE__ ) ) ); ?>' target="_blank"><?php esc_html_e( 'Learn More', 'disable-wordpress-automatic-updates-theme-editors' ); ?></a>
		</div>
	</span>
	<p class="dawufeg_nonaccess">
		<?php esc_html_e( 'You do not have ', 'disable-wordpress-automatic-updates-theme-editors' ); ?>
		<a href="<?php echo esc_url( 'https://wordpress.org/support/article/changing-file-permissions/' ); ?>">
			<?php esc_html_e( ' Write', 'disable-wordpress-automatic-updates-theme-editors' ); ?>
		</a>
		<?php esc_html_e( ' permisson to wp_config.php file this option will not work', 'disable-wordpress-automatic-updates-theme-editors' ); ?>
	</p>
	<?php
}

/**
 *  Display button for disable theme and plugin editor setting.
 */
function dawufeg_wordpress_editor_callback() {
	?>
	<label class="dawufeg-switch" for="dawufeg_editor">
		<input type="checkbox" id="dawufeg_editor" name="dawufeg_editor" value="1" <?php echo checked( 1, get_option( 'dawufeg_editor' ), false ); ?>/>
		<span class="dawufeg-slider dawufeg-round"></span>
	</label>
	<span class="setting-help-tip">
		<div class="tooltipdata">
			<?php esc_html_e( 'Allows you the ability to edit theme and plugin files directly from within the WordPress control panel.', 'disable-wordpress-automatic-updates-theme-editors' ); ?> 
		</div>
	</span>
	<p class="dawufeg_nonaccess"><?php esc_html_e( 'You do not have ', 'disable-wordpress-automatic-updates-theme-editors' ); ?><a href="<?php echo esc_url( 'https://wordpress.org/support/article/changing-file-permissions/' ); ?>"><?php esc_html_e( ' Write', 'disable-wordpress-automatic-updates-theme-editors' ); ?></a><?php esc_html_e( ' permisson to wp_config.php file this option will not work', 'disable-wordpress-automatic-updates-theme-editors' ); ?></p>
	<?php
}

/**
 * Display switch for gutenburg editor setting.
 */
function dawufeg_wordpress_gutenburg_callback() {
	?>
	<label class="dawufeg-switch" for="dawufeg_gutenburg">
		<input type="checkbox" id="dawufeg_gutenburg" name="dawufeg_gutenburg" value="1" <?php echo checked( 1, get_option( 'dawufeg_gutenburg' ), false ); ?>/>
		<span class="dawufeg-slider dawufeg-round"></span>
	</label>
	<span class="setting-help-tip">
		<div class="tooltipdata">
			<?php esc_html_e( 'Enabling this setting will disable the Gutenberg block editor on your posts and pages.', 'disable-wordpress-automatic-updates-theme-editors' ); ?>
		</div>
	</span>
	<?php
}

/**
 * Display switch for gutenburg widget setting.
 */
function dawufeg_wordpress_gutenburgwidgt_callback() {
	?>
	<label class="dawufeg-switch" for="dawufeg_gutenburg_widget">
		<input type="checkbox" id="dawufeg_gutenburg_widget" name="dawufeg_gutenburg_widget" value="1" <?php echo checked( 1, get_option( 'dawufeg_gutenburg_widget' ), false ); ?>/>
		<span class="dawufeg-slider dawufeg-round"></span>
	</label>
	<span class="setting-help-tip">
		<div class="tooltipdata">
			<?php esc_html_e( 'Enabling this setting will disable the Gutenberg block editor on your widgets.', 'disable-wordpress-automatic-updates-theme-editors' ); ?>
		</div>
	</span>
	<?php
}

/**
 * Display switch for WP_DEBUG setting.
 */
function dawufeg_wordpress_debug_callback() {
	?>
	<label class="dawufeg-switch" for="dawufeg_debug">
		<input type="checkbox" id="dawufeg_debug" name="dawufeg_debug" value="1" <?php echo checked( 1, get_option( 'dawufeg_debug' ), false ); ?>/>
		<span class="dawufeg-slider dawufeg-round"></span>
	</label>
	<span class="setting-help-tip">
		<div class="tooltipdata">
			<?php esc_html_e( 'Enable this setting if you want to enable "debug" mode throughout the website. Learn more on Debugging', 'disable-wordpress-automatic-updates-theme-editors' ); ?> <a class="learn-more" href="<?php echo esc_url( 'https://wordpress.org/support/article/debugging-in-wordpress/' ); ?>"><?php esc_html_e( ' here', 'disable-wordpress-automatic-updates-theme-editors' ); ?></a>
		</div>
	</span>
	<span class="dawufeg_note"><?php esc_html_e( ' Note: Refresh page once to see changes!', 'disable-wordpress-automatic-updates-theme-editors' ); ?></span>
	<p class="dawufeg_nonaccess"><?php esc_html_e( 'You do not have ', 'disable-wordpress-automatic-updates-theme-editors' ); ?><a href="<?php echo esc_url( 'https://wordpress.org/support/article/changing-file-permissions/' ); ?>"><?php esc_html_e( ' Write', 'disable-wordpress-automatic-updates-theme-editors' ); ?></a><?php esc_html_e( ' permisson to wp_config.php file this option will not work', 'disable-wordpress-automatic-updates-theme-editors' ); ?></p>
	<?php
}

/**
 * Display switch for debug log setting.
 */
function dawufeg_wordpress_debug_log_callback() {
	?>
	<label class="dawufeg-switch" for="dawufeg_debug_log">
		<input type="checkbox" id="dawufeg_debug_log" name="dawufeg_debug_log" value="1" <?php echo checked( 1, get_option( 'dawufeg_debug_log' ), false ); ?>/>
		<span class="dawufeg-slider dawufeg-round"></span>
	</label>
	<span class="setting-help-tip">
		<div class="tooltipdata">
			<?php esc_html_e( 'Enable this setting to enable Debug logging to the /wp-content/debug.log file', 'disable-wordpress-automatic-updates-theme-editors' ); ?>
		</div>
	</span>
	<p class="dawufeg_nonaccess"><?php esc_html_e( 'You do not have ', 'disable-wordpress-automatic-updates-theme-editors' ); ?><a href="<?php echo esc_url( 'https://wordpress.org/support/article/changing-file-permissions/' ); ?>"><?php esc_html_e( ' Write', 'disable-wordpress-automatic-updates-theme-editors' ); ?></a><?php esc_html_e( ' permisson to wp_config.php file this option will not work', 'disable-wordpress-automatic-updates-theme-editors' ); ?></p>
	<?php
}

/**
 * Display switch for debug display setting.
 */
function dawufeg_wordpress_debug_display_callback() {
	?>
	<label class="dawufeg-switch" for="dawufeg_debug_display">
		<input type="checkbox" id="dawufeg_debug_display" name="dawufeg_debug_display" value="1" <?php echo checked( 1, get_option( 'dawufeg_debug_display' ), false ); ?>/>
		<span class="dawufeg-slider dawufeg-round"></span>
	</label>
	<span class="setting-help-tip">
		<div class="tooltipdata">
			<?php esc_html_e( 'Enable this setting to enable display of errors and warnings', 'disable-wordpress-automatic-updates-theme-editors' ); ?>
		</div>
	</span>
	<span class="dawufeg_note"><?php esc_html_e( ' Note: Refresh page once to see changes!', 'disable-wordpress-automatic-updates-theme-editors' ); ?></span>
	<p class="dawufeg_nonaccess"><?php esc_html_e( 'You do not have ', 'disable-wordpress-automatic-updates-theme-editors' ); ?><a href="<?php echo esc_url( 'https://wordpress.org/support/article/changing-file-permissions/' ); ?>"><?php esc_html_e( ' Write', 'disable-wordpress-automatic-updates-theme-editors' ); ?></a><?php esc_html_e( ' permisson to wp_config.php file this option will not work', 'disable-wordpress-automatic-updates-theme-editors' ); ?></p>
	<?php
}

/**
 * Display switch for FS_METHOD setting.
 */
function dawufeg_wordpress_fsmethod_callback() {
	?>
	<label class="dawufeg-switch" for="dawufeg_fs_method">
		<input type="checkbox" id="dawufeg_fs_method" name="dawufeg_fs_method" value="1" <?php echo checked( 1, get_option( 'dawufeg_fs_method' ), false ); ?>/>
		<span class="dawufeg-slider dawufeg-round"></span>
	</label>
	<span class="setting-help-tip">
		<div class="tooltipdata">
			<?php esc_html_e( "When WordPress needs to install files (such as a plugin) it tries to determine a safe way to access the filesystem. In the process, it'll try to detect whether you're in an at-risk environment and if it thinks you're safe it will use the 'direct' method. Enabling this setting will set constant FS_METHOD = 'direct' and that will ask WordPress to bypass this at-risk detection and always create files using the 'direct' method.", 'disable-wordpress-automatic-updates-theme-editors' ); ?>
		</div>
	</span>
	<p class="dawufeg_nonaccess"><?php esc_html_e( 'You do not have ', 'disable-wordpress-automatic-updates-theme-editors' ); ?><a href="<?php echo esc_url( 'https://wordpress.org/support/article/changing-file-permissions/' ); ?>"><?php esc_html_e( ' Write', 'disable-wordpress-automatic-updates-theme-editors' ); ?></a><?php esc_html_e( ' permisson to wp_config.php file this option will not work', 'disable-wordpress-automatic-updates-theme-editors' ); ?></p>
	<?php
}


/**
 * Register and add settings field.
 */
function dawufeg_add_register_settings() {

	// Register setting for major minor update.
	register_setting( 'dawufeg_setting', 'dawufeg_core_major' );
	register_setting( 'dawufeg_setting', 'dawufeg_core_minor' );

	// Register setting for plugin and theme update.
	register_setting( 'dawufeg_setting', 'dawufeg_plugin' );
	register_setting( 'dawufeg_setting', 'dawufeg_theme' );

	// Register setting for theme plugin uploads and editor.
	register_setting( 'dawufeg_setting', 'dawufeg_uploads' );
	register_setting( 'dawufeg_setting', 'dawufeg_editor' );

	// Register setting for guternburg option.
	register_setting( 'dawufeg_setting', 'dawufeg_gutenburg' );
	register_setting( 'dawufeg_setting', 'dawufeg_gutenburg_widget' );

	// Register setting for debug and fs method option.
	register_setting( 'dawufeg_setting', 'dawufeg_debug' );
	register_setting( 'dawufeg_setting', 'dawufeg_debug_log' );
	register_setting( 'dawufeg_setting', 'dawufeg_debug_display' );
	register_setting( 'dawufeg_setting', 'dawufeg_fs_method' );

	// updates setting section.
	add_settings_section( 'dawufeg_update_setting_section', __( 'WordPress Updates Settings', 'disable-wordpress-automatic-updates-theme-editors' ), null, 'dawufeg_setting' );

	// setting field for major core update.
	add_settings_field( 'dawufeg_major_core_updates', __( 'Disable Major Updates', 'disable-wordpress-automatic-updates-theme-editors' ), 'dawufeg_wordpress_major_updates_callback', 'dawufeg_setting', 'dawufeg_update_setting_section' );

	// setting field for minor update handeling.
	add_settings_field( 'dawufeg_minor_core_updates', __( 'Disable Minor Updates', 'disable-wordpress-automatic-updates-theme-editors' ), 'dawufeg_wordpress_minor_updates_callback', 'dawufeg_setting', 'dawufeg_update_setting_section' );

	// themes and plugin setting section.
	add_settings_section( 'dawufeg_themes_setting_section', __( "Themes & Plugin's Updates & Editor's Settings", 'disable-wordpress-automatic-updates-theme-editors' ), null, 'dawufeg_setting' );

	// setting field for managing auto plugin update.
	add_settings_field( 'dawufeg_plugin_updates', __( 'Disable Automatic Plugin Updates', 'disable-wordpress-automatic-updates-theme-editors' ), 'dawufeg_wordpress_plugin_updates_callback', 'dawufeg_setting', 'dawufeg_themes_setting_section' );

	// setting field for managing theme & plugin editor.
	add_settings_field( 'dawufeg_theme_editor', __( 'Disable Theme & Plugin Editor', 'disable-wordpress-automatic-updates-theme-editors' ), 'dawufeg_wordpress_editor_callback', 'dawufeg_setting', 'dawufeg_themes_setting_section' );

	// setting field for managing updating and upload plugin.
	add_settings_field( 'dawufeg_modification_updates', __( 'Disable Plugin & Theme Upload & Manual Updates', 'disable-wordpress-automatic-updates-theme-editors' ), 'dawufeg_wordpress_uploading_callback', 'dawufeg_setting', 'dawufeg_themes_setting_section' );

	// setting field for managing auto theme update.
	add_settings_field( 'dawufeg_theme_updates', __( 'Disable Automatic Theme Updates', 'disable-wordpress-automatic-updates-theme-editors' ), 'dawufeg_wordpress_theme_updates_callback', 'dawufeg_setting', 'dawufeg_themes_setting_section' );

	// Gutenburg setting section.
	add_settings_section( 'dawufeg_gutenburg_setting_section', __( 'Gutenberg Settings', 'disable-wordpress-automatic-updates-theme-editors' ), null, 'dawufeg_setting' );

	// setting field for disabling gutenburg default editor.
	add_settings_field( 'dawufeg_gutenburg', __( 'Disable Gutenberg Editor', 'disable-wordpress-automatic-updates-theme-editors' ), 'dawufeg_wordpress_gutenburg_callback', 'dawufeg_setting', 'dawufeg_gutenburg_setting_section' );

	// setting field for disabling gutenburg widget.
	add_settings_field( 'dawufeg_gutenburg_widget', __( 'Disable Block Widget', 'disable-wordpress-automatic-updates-theme-editors' ), 'dawufeg_wordpress_gutenburgwidgt_callback', 'dawufeg_setting', 'dawufeg_gutenburg_setting_section' );

	// debug setting section.
	add_settings_section( 'dawufeg_debug_setting_section', __( 'WordPress Debugging / other settings', 'disable-wordpress-automatic-updates-theme-editors' ), null, 'dawufeg_setting' );

	// setting field for disabling wp_debug.
	add_settings_field( 'dawufeg_debug', __( 'Enable WP_DEBUG', 'disable-wordpress-automatic-updates-theme-editors' ), 'dawufeg_wordpress_debug_callback', 'dawufeg_setting', 'dawufeg_debug_setting_section' );

	// setting field for disabling wp_debug log.
	add_settings_field( 'dawufeg_debug_log', __( 'Enable WP_DEBUG_LOG', 'disable-wordpress-automatic-updates-theme-editors' ), 'dawufeg_wordpress_debug_log_callback', 'dawufeg_setting', 'dawufeg_debug_setting_section' );

	// setting field for disabling wp_debug display.
	add_settings_field( 'dawufeg_debug_display', __( 'Enable WP_DEBUG_DISPLAY', 'disable-wordpress-automatic-updates-theme-editors' ), 'dawufeg_wordpress_debug_display_callback', 'dawufeg_setting', 'dawufeg_debug_setting_section' );

	// setting field for changing fs_method to direct.
	add_settings_field( 'dawufeg_fs_method', __( "Set FS_METHOD to 'Direct'", 'disable-wordpress-automatic-updates-theme-editors' ), 'dawufeg_wordpress_fsmethod_callback', 'dawufeg_setting', 'dawufeg_debug_setting_section' );
}
add_action( 'admin_init', 'dawufeg_add_register_settings' );

/**
 * Create a sub menu on setting page.
 */
function dawufeg_add_setting_menu() {
	add_submenu_page(
		'options-general.php',
		__( 'Disable Updates', 'disable-wordpress-automatic-updates-theme-editors' ),
		__( 'Disable Updates', 'disable-wordpress-automatic-updates-theme-editors' ),
		'manage_options',
		'dawufeg-disable-menu',
		'dawufeg_get_options'
	);
}

/**
 * Use to display setting heading and show all option.
 */
function dawufeg_get_options() {
	?>
	<h1 id='setting-head'><?php esc_html_e( 'Settings for Disabling Updates, Theme Editors & Gutenburg', 'disable-wordpress-automatic-updates-theme-editors' ); ?></h1>
	<form action="options.php" method="post" id="dawufeg_status">
	<?php
		do_settings_sections( 'dawufeg_setting' );
		settings_fields( 'dawufeg_setting' );
		submit_button( __( 'Save Settings', 'disable-wordpress-automatic-updates-theme-editors' ) );
	?>
	</form>
	<?php
}
add_action( 'admin_menu', 'dawufeg_add_setting_menu' );

/**
 * Update rate Notice.
 */
function dawufeg_ajax_update_notice() {
	global $current_user;
	if ( isset( $_POST['nonce'] ) && ! empty( $_POST['nonce'] ) ) {
		if ( ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'disable-wordpress-automatic-updates-theme-editors' ) ) {
			wp_die( esc_html__( 'Permission Denied.', 'disable-wordpress-automatic-updates-theme-editors' ) );
		}

		update_user_meta( $current_user->ID, 'dawufeg_rate_notices', 'rated' );
		echo esc_url( network_admin_url() );
	}

	wp_die();
}

add_action( 'wp_ajax_dawufeg_update', 'dawufeg_ajax_update_notice' );
add_action( 'wp_ajax_nopriv_dawufeg_update', 'dawufeg_ajax_update_notice' );


/**
 * Rating notice widget.
 * Save the date to display notice after 10 days.
 */
function dawufeg_plugin_notice() {
	global $current_user;

	// if plugin is activated and date is not set then set the next 10 days.
	$today_date = strtotime( 'now' );

	if ( ! get_user_meta( $current_user->ID, 'dawufeg_notices_time' ) ) {
		$after_10_day = strtotime( '+10 day', $today_date );
		update_user_meta( $current_user->ID, 'dawufeg_notices_time', $after_10_day );
	}

	// gets the option of user rating status and week status.
	$rate_status = get_user_meta( $current_user->ID, 'dawufeg_rate_notices', true );
	$next_w_date = get_user_meta( $current_user->ID, 'dawufeg_notices_time', true );

	// show if user has not rated the plugin and it has been 1 week.
	if ( 'rated' !== $rate_status && $today_date > $next_w_date ) {
		?>
		<div class="notice notice-warning is-dismissible">
			<p><span><?php esc_html_e( "Awesome, you've been using", 'disable-wordpress-automatic-updates-theme-editors' ); ?></span><span><?php echo '<strong> Disable All Automatic Updates and Theme Editors</strong>'; ?><span><?php esc_html_e( 'for more than 1 week', 'disable-wordpress-automatic-updates-theme-editors' ); ?></span></p>
			<p><?php esc_html_e( 'If you like our plugin Would you like to rate our plugin at WordPress.org ?', 'disable-wordpress-automatic-updates-theme-editors' ); ?></p>
			<span><a href="https://wordpress.org/plugins/disable-automatic-updates-and-theme-editors/#reviews" target="_blank"><?php esc_html_e( "Yes, I'd like to rate it!", 'disable-wordpress-automatic-updates-theme-editors' ); ?></a></span>&nbsp; - &nbsp;<span><a class="dawufeg_hide_rate" href="#"><?php esc_html_e( 'I already did!', 'disable-wordpress-automatic-updates-theme-editors' ); ?></a></span>
			<br/><br/>
		</div>
		<?php
	}
}
add_action( 'admin_notices', 'dawufeg_plugin_notice' );
