<?php

/**
 * Change user capability for editing plugin and theme file.
 *
 * @param string $allcaps .
 * @param string $caps .
 * @param mixed  $args .
 * @param string $user .
 * @return array
 */
function dawufeg_change_theme_plugin_editor_cap( $allcaps, $caps, $args, $user ) {

	// echo 'askdajdladja;dsja;dsj;asd;jas;jd;jasd;ja;jlsd:  ' . get_option( 'dawufeg_editor' );
	// Disable file and theme editor if option is enable.
	if ( get_option( 'dawufeg_editor' ) || 1 === get_option( 'dawufeg_editor' ) ) {
		update_option( 'dawufeg_editor', 1 );
		$allcaps['edit_plugins'] = false;
		$allcaps['edit_themes']  = false;
	} else {
		$allcaps['edit_plugins'] = true;
		$allcaps['edit_themes']  = true;
	}
	return $allcaps;
}


/**
 * Change constant on radio button enabled/disabled for file edit.
 */
function dawufeg_theme_plugin_edit_constant_change() {

	// on first time plugin install enbale option for file edit.
	if ( 'first' !== get_option( 'edit_filter_first_time' ) ) {
		update_option( 'dawufeg_editor', 1 );
		add_option( 'edit_filter_first_time', 'first' );
	}
	add_filter( 'user_has_cap', 'dawufeg_change_theme_plugin_editor_cap', 11, 4 );
}


/**
 * Change capability for theme and plugin manual upload.
 *
 * @param string $allcaps .
 * @param string $caps .
 * @param mixed  $args .
 * @param string $user .
 * @return array
 */
function dawufeg_change_theme_plugin_cap( $allcaps, $caps, $args, $user ) {

	// List of capability for file upload of theme and plugin.
	$user_cap = array( 'install_themes', 'delete_themes', 'install_plugins', 'delete_plugins' );

	// Disable file uploads and theme upload button if manual update button is on.
	if ( get_option( 'dawufeg_uploads' ) || 1 === get_option( 'dawufeg_uploads' ) ) {
		update_option( 'dawufeg_uploads', 1 ); // update the option.

		// Make all capability false.
		foreach ( $user_cap as $cap ) {
			$allcaps[ $cap ] = false;
		}
	}
	return $allcaps;
}

/**
 * Disallow plugin manual updates.
 */
function dawufeg_theme_plugin_modification_constant_change() {

	// On first time plugin install enable option for Plugin & Theme Upload & Manual Updates.
	if ( 'first' !== get_option( 'upload_filter_first_time' ) ) {
		update_option( 'dawufeg_uploads', 1 ); // on theme update and manual button is on.
		add_filter( 'site_transient_update_plugins', '__return_true' );
		add_filter( 'site_transient_update_themes', '__return_true' );
		add_option( 'upload_filter_first_time', 'first' );
	} else {

		// If Plugin & Theme Upload & Manual Updates option is on then on the filter.
		if ( get_option( 'dawufeg_uploads' ) || 1 === get_option( 'dawufeg_uploads' ) ) {
			add_filter( 'site_transient_update_plugins', '__return_true' );
			add_filter( 'site_transient_update_themes', '__return_true' );
		}
	}
	add_filter( 'user_has_cap', 'dawufeg_change_theme_plugin_cap', 11, 4 );
}


/**
 *  Handels theme & plugin updates settings.
 */
function dawufeg_theme_plugin_setting_callback() {
	// phpcs:disable WordPress.Security.NonceVerification.Recommended

	$config_file_path = strval( dawufeg_get_config_path() ); // config file path.

	// if config file exist and have write permission.
	if ( $config_file_path && file_exists( $config_file_path ) ) {
		if ( is_writable( $config_file_path ) && current_user_can( 'manage_options' ) ) {
			$config_transformer = new \WPConfigTransformer( $config_file_path );
		}
	}

	// managing wp-config for define( 'DISALLOW_FILE_MODS' ).
	if ( is_writable( $config_file_path ) && current_user_can( 'manage_options' ) ) {

		// If already define file mods.
		if ( defined( 'DISALLOW_FILE_MODS' ) ) {

			// set file mod to false by default if it is kept on.
			if ( 1 === intval( constant( 'DISALLOW_FILE_MODS' ) ) ) {

				// Make constant disallow file mod false.
				try {
					$config_transformer->update( 'constant', 'DISALLOW_FILE_MODS', 'false', array( 'raw' => true ) );
				} catch ( \Exception $ex ) {
					add_action( 'admin_notices', 'dawufeg_error_update_notices_callback' );
				}
			}
		}
	} else {

		// read constant value if defined and enable option based on that.
		if ( defined( 'DISALLOW_FILE_MODS' ) ) {

			// if dissallow file mod is enabled on the theme upload.
			if ( in_array( strtolower( strval( constant( 'DISALLOW_FILE_MODS' ) ) ), array( '1', '' ), true ) ) {
				if ( 1 === intval( constant( 'DISALLOW_FILE_MODS' ) ) ) {
					update_option( 'dawufeg_uploads', 1 );
				} else {
					update_option( 'dawufeg_uploads', 0 );
				}
			} else {
				update_option( 'dawufeg_uploads', 0 );
			}
		} else {
			update_option( 'dawufeg_uploads', 0 );
		}
	}

	// if wp-config file is writable for define( 'DISALLOW_FILE_EDIT' ).
	if ( is_writable( $config_file_path ) && current_user_can( 'manage_options' ) ) {

		// If file edit constant is defined.
		if ( defined( 'DISALLOW_FILE_EDIT' ) ) {

			// if constant is set to true update checkbox and on false change make constant true.
			if ( 'first' !== get_option( 'edit_first_time' ) ) {

				update_option( 'dawufeg_editor', 1 ); // default enable editor option.

				// if invalid value on constant.
				if ( ! in_array( strtolower( strval( constant( 'DISALLOW_FILE_EDIT' ) ) ), array( '1', '' ), true ) ) {

					// updating constant to true.
					try {
						$config_transformer->update( 'constant', 'DISALLOW_FILE_EDIT', 'true', array( 'raw' => true ) );
						update_option( 'dawufeg_editor', 1 );
					} catch ( \Exception $ex ) {
						add_action( 'admin_notices', 'dawufeg_error_update_notices_callback' );
						update_option( 'dawufeg_editor', 0 );
					}
				} elseif ( in_array( strtolower( strval( constant( 'DISALLOW_FILE_EDIT' ) ) ), array( '1', '' ), true ) ) { // on valid value of constant.

					// if file edit is set false defaulting to true otherwise just update switch value.
					if ( 1 === intval( constant( 'DISALLOW_FILE_EDIT' ) ) ) {
						update_option( 'dawufeg_editor', 1 );
					} else {

						// updating constant to true.
						try {
							$config_transformer->update( 'constant', 'DISALLOW_FILE_EDIT', 'true', array( 'raw' => true ) );
							update_option( 'dawufeg_editor', 1 );
						} catch ( \Exception $ex ) {
							add_action( 'admin_notices', 'dawufeg_error_update_notices_callback' );
							update_option( 'dawufeg_editor', 0 );
						}
					}
				}
				add_option( 'edit_first_time', 'first' ); // done first time update after plugin is installed.
			} elseif ( 'first' === get_option( 'edit_first_time' ) && ! isset( $_GET['settings-updated'] ) ) { // if normal refresh done on setting page.

				// if invalid value.
				if ( ! in_array( strtolower( strval( constant( 'DISALLOW_FILE_EDIT' ) ) ), array( '1', '' ), true ) ) {

					// update constant value to true.
					try {
						$config_transformer->update( 'constant', 'DISALLOW_FILE_EDIT', 'true', array( 'raw' => true ) );
						update_option( 'dawufeg_editor', 1 );
					} catch ( \Exception $ex ) {
						add_action( 'admin_notices', 'dawufeg_error_update_notices_callback' );
						update_option( 'dawufeg_editor', 0 );
					}
				} elseif ( in_array( strtolower( strval( constant( 'DISALLOW_FILE_EDIT' ) ) ), array( '1', '' ), true ) ) {

					// if file edit is set false or true update option.
					if ( 1 === intval( constant( 'DISALLOW_FILE_EDIT' ) ) ) {
						update_option( 'dawufeg_editor', 1 );
					} else {
						update_option( 'dawufeg_editor', 0 );
					}
				}
			} elseif ( 'first' === get_option( 'edit_first_time' ) && isset( $_GET['settings-updated'] ) ) { // if setting button pressed and updated.

				// If settings option is not kept on.
				if ( empty( get_option( 'dawufeg_editor' ) ) || 0 === get_option( 'dawufeg_editor' ) ) {

					// update constant to false.
					try {
						$config_transformer->update( 'constant', 'DISALLOW_FILE_EDIT', 'false', array( 'raw' => true ) );
						update_option( 'dawufeg_editor', 0 );
					} catch ( \Exception $ex ) {
						add_action( 'admin_notices', 'dawufeg_error_update_notices_callback' );
						update_option( 'dawufeg_editor', 1 );
					}
				} else { // if setting condition is kept on.

					// update constant to true.
					try {
						$config_transformer->update( 'constant', 'DISALLOW_FILE_EDIT', 'true', array( 'raw' => true ) );
						update_option( 'dawufeg_editor', 1 );
					} catch ( \Exception $ex ) {
						add_action( 'admin_notices', 'dawufeg_error_update_notices_callback' );
						update_option( 'dawufeg_editor', 0 );
					}
				}
			}
		} else {
			dawufeg_theme_plugin_edit_constant_change();
		}
	} else {

		// read constant value if defined and enable option based on that.
		if ( defined( 'DISALLOW_FILE_EDIT' ) ) {

			// if constant has valid value.
			if ( in_array( strtolower( strval( constant( 'DISALLOW_FILE_EDIT' ) ) ), array( '1', '' ), true ) ) {

				if ( 1 === intval( constant( 'DISALLOW_FILE_EDIT' ) ) ) {
					update_option( 'dawufeg_editor', 1 );
				} else {
					update_option( 'dawufeg_editor', 0 );
				}
			} else {
				update_option( 'dawufeg_editor', 0 );
			}
		} else {
			update_option( 'dawufeg_editor', 0 );
		}
	}

	// Works for Plugin & Theme Upload & Manual Updates.
	if ( 'first' !== get_option( 'manual_upload_first_time' ) ) {
		update_option( 'dawufeg_uploads', 1 ); // enable default options.
		dawufeg_theme_plugin_modification_constant_change(); // run the filter.
		add_option( 'manual_upload_first_time', 'first' );
	} elseif ( 'first' === get_option( 'manual_upload_first_time' ) ) {
		dawufeg_theme_plugin_modification_constant_change();
	}

	// Work for automatic plugin and theme updates.
	if ( 'first' !== get_option( 'plugin_first_time' ) ) {
		update_option( 'dawufeg_plugin', 1 ); // default enable option for plugin auto update.
		update_option( 'dawufeg_theme', 1 ); // default enable option for theme auto update.
		add_option( 'plugin_first_time', 'first' );
	} elseif ( 'first' === get_option( 'plugin_first_time' ) ) {

		// checks the option auto update plugin and enable or disable it.
		if ( empty( get_option( 'dawufeg_plugin' ) ) || 0 === get_option( 'dawufeg_plugin' ) ) {
			add_filter( 'auto_update_plugin', '__return_true' );
		} else {
			add_filter( 'auto_update_plugin', '__return_false' );
		}

		// checks the option auto update theme and enable or disable it.
		if ( empty( get_option( 'dawufeg_theme' ) ) || 0 === get_option( 'dawufeg_theme' ) ) {
			add_filter( 'auto_update_theme', '__return_true' );
		} else {
			add_filter( 'auto_update_theme', '__return_false' );
		}
	}
}
